<!-- The following items are listed to help you get your issue resolved quickly -->
## Checklist
- [ ] I am running the latest version. Installing Isso from GitHub from the `master` branch does not fix my issue
- [ ] I have checked the [troubleshooting guide](https://isso-comments.de/docs/guides/troubleshooting/)
- [ ] I have searched the [open issues](https://github.com/isso-comments/isso/issues), but my issue has not already been reported

## What is not working?
<!-- Explain your issue in detail -->
...

## How can one reproduce this issue?
<!-- Post your isso.cfg, other relevant configuration/setup -->
...
